Release 1.3.1
=============

This is a minor release that adds some utilities and fixes some issues with Python 3 bytes/str.

Changes for developers
----------------------

 - Added utilities developed at ISIS.

 - Use bytes in unsolicited reply (Python 3 fix)

 - Add ability to send bytes to lewis
